@@ -18,20 +18,18 @@ OpenStack Swift client library used internally
 """
 import socket
 import re
-import requests
 import logging
 import warnings
 
-from distutils.version import StrictVersion
 from requests.exceptions import RequestException, SSLError
-from six.moves import http_client
-from six.moves.urllib.parse import quote as _quote, unquote
-from six.moves.urllib.parse import urljoin, urlparse, urlunparse
+import http.client as http_client
+from urllib.parse import quote as _quote, unquote
+from urllib.parse import urljoin, urlparse, urlunparse
 from time import sleep, time
-import six
 
 from swiftclient import version as swiftclient_version
 from swiftclient.exceptions import ClientException
+from swiftclient.requests_compat import SwiftClientRequestsSession
 from swiftclient.utils import (
     iter_wrapper, LengthWrapper, ReadableToIterable, parse_api_response,
     get_body)
@@ -48,25 +46,11 @@ USER_METADATA_TYPE = tuple('x-%s-meta-' % type_ for type_ in
 URI_PATTERN_INFO = re.compile(r'/info')
 URI_PATTERN_VERSION = re.compile(r'\/v\d+\.?\d*(\/.*)?')
 
-try:
-    from logging import NullHandler
-except ImportError:
-    # Added in Python 2.7
-    class NullHandler(logging.Handler):
-        def handle(self, record):
-            pass
-
-        def emit(self, record):
-            pass
-
-        def createLock(self):
-            self.lock = None
-
 ksexceptions = ksclient_v2 = ksclient_v3 = ksa_v3 = None
 try:
     from keystoneclient import exceptions as ksexceptions
     # prevent keystoneclient warning us that it has no log handlers
-    logging.getLogger('keystoneclient').addHandler(NullHandler())
+    logging.getLogger('keystoneclient').addHandler(logging.NullHandler())
     from keystoneclient.v2_0 import client as ksclient_v2
 except ImportError:
     pass
@@ -78,22 +62,8 @@ try:
 except ImportError:
     pass
 
-# requests version 1.2.3 try to encode headers in ascii, preventing
-# utf-8 encoded header to be 'prepared'. This also affects all
-# (or at least most) versions of requests on py3
-if StrictVersion(requests.__version__) < StrictVersion('2.0.0') \
-        or not six.PY2:
-    from requests.structures import CaseInsensitiveDict
-
-    def prepare_unicode_headers(self, headers):
-        if headers:
-            self.headers = CaseInsensitiveDict(headers)
-        else:
-            self.headers = CaseInsensitiveDict()
-    requests.models.PreparedRequest.prepare_headers = prepare_unicode_headers
-
 logger = logging.getLogger("swiftclient")
-logger.addHandler(NullHandler())
+logger.addHandler(logging.NullHandler())
 
 #: Default behaviour is to redact header values known to contain secrets,
 #: such as ``X-Auth-Key`` and ``X-Auth-Token``. Up to the first 16 chars
@@ -194,34 +164,20 @@ def http_log(args, kwargs, resp, body):
 
 
 def parse_header_string(data):
-    if not isinstance(data, (six.text_type, six.binary_type)):
+    if not isinstance(data, (str, bytes)):
         data = str(data)
-    if six.PY2:
-        if isinstance(data, six.text_type):
-            # Under Python2 requests only returns binary_type, but if we get
-            # some stray text_type input, this should prevent unquote from
-            # interpreting %-encoded data as raw code-points.
-            data = data.encode('utf8')
+    if isinstance(data, bytes):
+        # Under Python3 requests only returns text_type and tosses (!) the
+        # rest of the headers. If that ever changes, this should be a sane
+        # approach.
         try:
-            unquoted = unquote(data).decode('utf8')
+            data = data.decode('ascii')
         except UnicodeDecodeError:
-            try:
-                return data.decode('utf8')
-            except UnicodeDecodeError:
-                return quote(data).decode('utf8')
-    else:
-        if isinstance(data, six.binary_type):
-            # Under Python3 requests only returns text_type and tosses (!) the
-            # rest of the headers. If that ever changes, this should be a sane
-            # approach.
-            try:
-                data = data.decode('ascii')
-            except UnicodeDecodeError:
-                data = quote(data)
-        try:
-            unquoted = unquote(data, errors='strict')
-        except UnicodeDecodeError:
-            return data
+            data = quote(data)
+    try:
+        unquoted = unquote(data, errors='strict')
+    except UnicodeDecodeError:
+        return data
     return unquoted
 
 
@@ -230,20 +186,18 @@ def quote(value, safe='/'):
     Patched version of urllib.quote that encodes utf8 strings before quoting.
     On Python 3, call directly urllib.parse.quote().
     """
-    if six.PY3:
-        return _quote(value, safe=safe)
-    return _quote(encode_utf8(value), safe)
+    return _quote(value, safe=safe)
 
 
 def encode_utf8(value):
-    if type(value) in six.integer_types + (float, bool):
+    if type(value) in (int, float, bool):
         # As of requests 2.11.0, headers must be byte- or unicode-strings.
         # Convert some known-good types as a convenience for developers.
         # Note that we *don't* convert subclasses, as they may have overriddden
         # __str__ or __repr__.
         # See https://github.com/kennethreitz/requests/pull/3366 for more info
         value = str(value)
-    if isinstance(value, six.text_type):
+    if isinstance(value, str):
         value = value.encode('utf8')
     return value
 
@@ -255,7 +209,7 @@ def encode_meta_headers(headers):
         value = encode_utf8(value)
         header = header.lower()
 
-        if (isinstance(header, six.string_types) and
+        if (isinstance(header, str) and
                 header.startswith(USER_METADATA_TYPE)):
             header = encode_utf8(header)
 
@@ -263,7 +217,7 @@ def encode_meta_headers(headers):
     return ret
 
 
-class _ObjectBody(object):
+class _ObjectBody:
     """
     Readable and iterable object body response wrapper.
     """
@@ -377,7 +331,7 @@ class _RetryBody(_ObjectBody):
         return buf
 
 
-class HTTPConnection(object):
+class HTTPConnection:
     def __init__(self, url, proxy=None, cacert=None, insecure=False,
                  cert=None, cert_key=None, ssl_compression=False,
                  default_user_agent=None, timeout=None):
@@ -412,7 +366,7 @@ class HTTPConnection(object):
         self.host = self.parsed_url.netloc
         self.port = self.parsed_url.port
         self.requests_args = {}
-        self.request_session = requests.Session()
+        self.request_session = SwiftClientRequestsSession()
         # Don't use requests's default headers
         self.request_session.headers = None
         self.resp = None
@@ -486,12 +440,12 @@ class HTTPConnection(object):
         old_getheader = self.resp.raw.getheader
 
         def _decode_header(string):
-            if string is None or six.PY2:
+            if string is None:
                 return string
             return string.encode('iso-8859-1').decode('utf-8')
 
         def _encode_header(string):
-            if string is None or six.PY2:
+            if string is None:
                 return string
             return string.encode('utf-8').decode('iso-8859-1')
 
@@ -1448,11 +1402,6 @@ def put_object(url, token=None, container=None, name=None, contents=None,
                 content_length = int(v)
     if content_type is not None:
         headers['Content-Type'] = content_type
-    elif 'Content-Type' not in headers:
-        if StrictVersion(requests.__version__) < StrictVersion('2.4.0'):
-            # python-requests sets application/x-www-form-urlencoded otherwise
-            # if using python3.
-            headers['Content-Type'] = ''
     if not contents:
         headers['Content-Length'] = '0'
 
@@ -1475,7 +1424,7 @@ def put_object(url, token=None, container=None, name=None, contents=None,
             warnings.warn(warn_msg, stacklevel=2)
         # Match requests's is_stream test
         if hasattr(contents, '__iter__') and not isinstance(contents, (
-                six.text_type, six.binary_type, list, tuple, dict)):
+                str, bytes, list, tuple, dict)):
             contents = iter_wrapper(contents)
         conn.request('PUT', path, contents, headers)
 
@@ -1685,7 +1634,7 @@ def get_capabilities(http_conn):
     return parse_api_response(resp_headers, body)
 
 
-class Connection(object):
+class Connection:
 
     """
     Convenience class to make requests that will also retry the request
